@@ -55,9 +55,12 @@ class MarshmallowValidatedRecordMixin:
             result = self.MARSHMALLOW_SCHEMA(context=context).load(data)
             after_marshmallow_validate.send(
                 self,
-                record=self, context=context, result=result, **validate_kwargs)
+                record=self, context=context, result=result, error=None, **validate_kwargs)
             return result
         except ValidationError as error:
+            after_marshmallow_validate.send(
+                self,
+                record=self, context=context, result=None, error=error, **validate_kwargs)
             raise MarshmallowErrors(error.messages)
 
     def patch(self, patch):
@@ -84,7 +87,7 @@ class MarshmallowValidatedRecordMixin:
         if kwargs.pop('validate_marshmallow', self.VALIDATE_MARSHMALLOW):
             data = self.validate_marshmallow(validate_kwargs=kwargs)
             self.update(data)
-        return super().validate(**kwargs)
+        return super().validate()   # do not pass kwargs along the stack
 
 
 class MarshmallowValidatedRecord(MarshmallowValidatedRecordMixin, Record):
